Exception: GoogleGeocoding::Errors::BadKeyError
- Inherits:
-
ServiceError
- Object
- StandardError
- BaseError
- ServiceError
- GoogleGeocoding::Errors::BadKeyError
- Defined in:
- lib/google_geocoding/errors.rb
Overview
610 G_GEO_BAD_KEY
Constant Summary
Constants inherited from ServiceError
Instance Method Summary collapse
-
#initialize ⇒ BadKeyError
constructor
A new instance of BadKeyError.
Methods inherited from ServiceError
Constructor Details
#initialize ⇒ BadKeyError
Returns a new instance of BadKeyError.
48 49 50 |
# File 'lib/google_geocoding/errors.rb', line 48 def initialize super("The given key is either invalid or does not match the domain for which it was given.") end |