Exception: GoogleGeocoding::Errors::ServerError

Inherits:
ServiceError show all
Defined in:
lib/google_geocoding/errors.rb

Overview

500 G_GEO_SERVER_ERROR

Constant Summary

Constants inherited from ServiceError

GoogleGeocoding::Errors::ServiceError::ERRORS_MAPPING

Instance Method Summary collapse

Methods inherited from ServiceError

build

Constructor Details

#initializeServerError

Returns a new instance of ServerError.



20
21
22
# File 'lib/google_geocoding/errors.rb', line 20

def initialize
  super("A geocoding or directions request could not be successfully processed, yet the exact reason for the failure is unknown.")
end