Exception: GoogleGeocoding::Errors::TooManyQueriesError

Inherits:
ServiceError show all
Defined in:
lib/google_geocoding/errors.rb

Overview

620 G_GEO_TOO_MANY_QUERIES

Constant Summary

Constants inherited from ServiceError

ServiceError::ERRORS_MAPPING

Instance Method Summary collapse

Methods inherited from ServiceError

build

Constructor Details

#initializeTooManyQueriesError

Returns a new instance of TooManyQueriesError.



55
56
57
# File 'lib/google_geocoding/errors.rb', line 55

def initialize
  super("The given key has gone over the requests limit in the 24 hour period or has submitted too many requests in too short a period of time. If you're sending multiple requests in parallel or in a tight loop, use a timer or pause in your code to make sure you don't send the requests too quickly.")
end