Exception: GoogleGeocoding::Errors::UnknownAddressError

Inherits:
ServiceError show all
Defined in:
lib/google_geocoding/errors.rb

Overview

602 G_GEO_UNKNOWN_ADDRESS

Constant Summary

Constants inherited from ServiceError

ServiceError::ERRORS_MAPPING

Instance Method Summary collapse

Methods inherited from ServiceError

build

Constructor Details

#initializeUnknownAddressError

Returns a new instance of UnknownAddressError.



34
35
36
# File 'lib/google_geocoding/errors.rb', line 34

def initialize
  super("No corresponding geographic location could be found for the specified address, possibly because the address is relatively new, or because it may be incorrect.")
end