Exception: GoogleGeocoding::Errors::BadKeyError

Inherits:
ServiceError show all
Defined in:
lib/google_geocoding/errors.rb

Overview

610 G_GEO_BAD_KEY

Constant Summary

Constants inherited from ServiceError

ServiceError::ERRORS_MAPPING

Instance Method Summary collapse

Methods inherited from ServiceError

build

Constructor Details

#initializeBadKeyError

Returns a new instance of BadKeyError.



48
49
50
# File 'lib/google_geocoding/errors.rb', line 48

def initialize
  super("The given key is either invalid or does not match the domain for which it was given.")
end