Exception: GoogleGeocoding::Errors::ServerError
- Inherits:
-
ServiceError
- Object
- StandardError
- BaseError
- ServiceError
- GoogleGeocoding::Errors::ServerError
- Defined in:
- lib/google_geocoding/errors.rb
Overview
500 G_GEO_SERVER_ERROR
Constant Summary
Constants inherited from ServiceError
GoogleGeocoding::Errors::ServiceError::ERRORS_MAPPING
Instance Method Summary collapse
-
#initialize ⇒ ServerError
constructor
A new instance of ServerError.
Methods inherited from ServiceError
Constructor Details
#initialize ⇒ ServerError
Returns a new instance of ServerError.
20 21 22 |
# File 'lib/google_geocoding/errors.rb', line 20 def initialize super("A geocoding or directions request could not be successfully processed, yet the exact reason for the failure is unknown.") end |